package sgc.portal.qc.qc0102.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.qc.qc0101.dto.QC01010001USearch;
import sgc.portal.qc.qc0102.dto.QC01020001USearch;

import java.util.List;
import java.util.Map;

@Mapper
public interface QC01020001UMapper {
	
	//eTEC Standard Doc
	List<EasyHashMap<String, Object>> selectQcStndPrcgList30(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndGudlList30(QC01020001USearch search);
	
	List<EasyHashMap<String, Object>> selectQcStndPrcgList(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndGudlList(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndPrcgFileList(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndGudlFileList(QC01020001USearch search);
	
	List<EasyHashMap<String, Object>> selectQcStndContextList(QC01020001USearch search);
	
	//1. 규정
	List<EasyHashMap<String, Object>> selectQcStndRList(QC01020001USearch search);
	
	//동적조회 세팅
	List<EasyHashMap<String, Object>> selectHeaderUpList1(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderDownList1(QC01020001USearch search);
	String selectName1(QC01020001USearch search);
	String selectName11(QC01020001USearch search);
	
	//2. 경영기획
	List<EasyHashMap<String, Object>> selectQcStndAList(QC01020001USearch search);
	
	//동적조회 세팅
	List<EasyHashMap<String, Object>> selectHeaderUpList2(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderDownList2(QC01020001USearch search);
	String selectName2(QC01020001USearch search);
	String selectName22(QC01020001USearch search);
	
	//3. 수주영업
	List<EasyHashMap<String, Object>> selectQcStndMList(QC01020001USearch search);
	
	//동적조회 세팅
	List<EasyHashMap<String, Object>> selectHeaderUpList3(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderDownList3(QC01020001USearch search);
	String selectName3(QC01020001USearch search);
	String selectName33(QC01020001USearch search);
	
	//4. 사업수행
	List<EasyHashMap<String, Object>> selectQcStndEList(QC01020001USearch search);
	
	//동적조회 세팅
	List<EasyHashMap<String, Object>> selectHeaderUpList4(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderDownList4(QC01020001USearch search);
	String selectName4(QC01020001USearch search);
	String selectName44(QC01020001USearch search);
	
	//5. 사업지원
	List<EasyHashMap<String, Object>> selectQcStndSList(QC01020001USearch search);
	
	//동적조회 세팅
	List<EasyHashMap<String, Object>> selectHeaderUpList5(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectHeaderDownList5(QC01020001USearch search);
	String selectName5(QC01020001USearch search);
	String selectName55(QC01020001USearch search);
	
	int selectQcStndRCount(QC01020001USearch search);
	int selectQcStndACount(QC01020001USearch search);
	int selectQcStndMCount(QC01020001USearch search);
	int selectQcStndECount(QC01020001USearch search);
	int selectQcStndSCount(QC01020001USearch search);
	
	///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
	
	//Standard e & c 조회
	//트리구조 조회
	List<EasyHashMap<String, Object>> selectQcStndTreeListNext(QC01020001USearch search);
	
	List<EasyHashMap<String, Object>> selectQcStndListNext(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndPrcgFrmtAflIdList(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndGudlNmList(QC01020001USearch search);
	
	
	//PDF 조회
	List<EasyHashMap<String, Object>> selectQcStndPrcgListNext(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndGudlListNext(QC01020001USearch search);
	
	//첨부파일 조회
	List<EasyHashMap<String, Object>> selectQcStndPrcgGudlAflIdListNext(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndPrcgHisFrmtAflIdListNext(QC01020001USearch search);
	List<EasyHashMap<String, Object>> selectQcStndGudlGudlRelAflIdListNext(QC01020001USearch search);
}
